@@ -239,7 +239,7 @@ def main(argv):
         ## Commit-push changes repository END
          
     if action == 'nexus':
-        setup_variables()
+        nexus.setup_variables()
         print("Nexus Format entered: ", nexus_format)
         if nexus_format == 'raw':
             nexus.upload_nexus_raw()
