@@ -2,11 +2,65 @@ import __main__
 
 def get_version_number():
     path = __main__.os.path.abspath(__main__.os.getcwd())
+    ## grep 'version\s*=\s*' setup.py  | tr -d 'version=' | tr -d ',' | awk '{print $1}' ## get version in python
     ##make provision to get version number from java type project
     process_result = __main__.subprocess.Popen("node -p \"require('./package.json').version\"", shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
     version_result = process_result.communicate()[0]
     return str(version_result, 'utf-8')
 
+def setup_variables():
+     if __main__.group_id == '':
+            __main__.group_id = __main__.os.environ.get('NEXUS_GROUP_ID')   
+        if __main__.group_id == '':
+            print("Fail to obtain Nexus group id from environment variables")
+
+    ## To-do: Fix artifact name
+    if __main__.artifact_name == '':
+       __main__.artifact_name = __main__.os.environ.get('CI_PROJECT_NAME')
+       ## Fix to add extension, right now it is just a folder
+       if __main__.artifact_name == '':
+           print("Could not obtain project name from git repository to use as artifact name")
+           return sys.exit(2)     
+    
+    if __main__.repository_name == '':
+       __main__.branch_name = __main__.os.environ.get('CI_COMMIT_BRANCH')
+       if __main__.branch_name == '':
+           print("Could not compute repository name to store to based on branch name e.g <organization>-snapshots")
+           return sys.exit(2)
+       else:
+           if 'master' == __main__.branch_name:
+               __main__.repository_name = 'egov-releases'
+           else:
+               __main__.repository_name = 'egov-snapshots'
+    if __main__.nexus_format == 'raw' and __main__.directory == '':
+        print("RAW nexus repository format requires a directory")
+        return sys.exit(2)
+      
+    if __main__.nexus_format == 'maven' and __main__.group_id == '':
+        print("Maven2 repository requires Group ID  e.g com.<organization>.<applicationname>")
+        return sys.exit(2)
+    
+    if __main__.username == '':
+        __main__.username = __main__.os.environ.get('NEXUS_USERNAME')
+        if __main__.username == '' or __main__.username is None:
+            print("Fail to retrieve Nexus username from environment variables")
+            return sys.exit(2)
+    
+    if __main__.password == '':
+        __main__.password = os.environ.get('NEXUS_PASSWORD')
+        if __main__.password == '' or __main__.password is None:
+            print("Fail to retrieve Nexus password from environment variables")
+            return sys.exit(2)
+    
+    if __main__.work_directory == '':
+        __main__.work_directory = __main__.os.path.abspath(os.getcwd())
+        
+    __main__.auth = (__main__.username, __main__.password)    
+    if 'service/rest' in  __main__.repository_base_url:
+        __main__.repository_full_url = __main__.repository_base_url
+    else: 
+        __main__.repository_full_url = __main__.repository_base_url + "/" + "service/rest/v1/components"
+    
 
 def upload_nexus_raw():
     params = (('repository', __main__.repository_name),)
